// See prfxstream.hh for the declarations and prfxstream.cc of [io]prfxstream.
//
// This application is a little bit fancy: It uses the name of the program to
// determine whether a the processing should be applied to the input or the
// output: If the program name starts with 'i' it is assumed that the program
// should read its standard input to strip off prefixes from these lines. The
// result is send to the standard ouptut. If the program name starts with 'o'
// it is assumed that the program should read its standard input and preceed
// every line with a prefix. The result is again send to the standard output.
// The prefix which is to be stripped off or to be prepended is the argument to
// the program. If either the program name doesn't start with 'o' or 'i' or
// there is no argument given, the program complains about this fact.

#include "prfxstream.hh"

using namespace std;

int main(
  int argc,
  char *argv[]
) {
  if (argc != 2) {
    cerr << "Usage: " << argv[0] << " <prefix>" << endl;
    exit(1);
  }

  if (argv[0][0] == 'o') {

    // The following is the line creating a stream which prefixes every line
    // written with a given prefix.  The output is actually send to the
    // streambuf indicated by the first argument.

    oprfxstream out(cout.rdbuf(), argv[1]);
    char c;

    while (cin)
      if (cin.get(c))
        out.put(c);
  } else if (argv[0][0] == 'i') {

    // The following is the line creating a stream which strips off a given
    // prefix from every line read. The input is actually read from the
    // streambuf indicated by the first argument.

    iprfxstream in(cin.rdbuf(), argv[1]);
    char c;

    while (in)
      if (in.get(c))
        cout.put(c);
  } else {
    cerr << "Programname doesn't start with 'i' or 'o'!" << endl;
  }
}
